@@ -2,8 +2,6 @@
 import io
 import logging
 import textwrap
-from base64 import urlsafe_b64encode
-from hashlib import shake_128
 from typing import Any
 
 import pandas as pd
@@ -81,30 +79,6 @@ def denull_df(df: pd.DataFrame, *, df_description: str = "dataframe", criteria_d
     return rate_kept
 
 
-def series_to_str_id(pd_series: pd.Series, /) -> str:
-    """Return a reproducibly random string ID of 128 bits which is 16 bytes which is 24 urlsafe base64 characters.
-
-    Usage pattern:
-    >>> assert len(df.drop_duplicates()) <= 2 ** 64
-    >>> df['xyz_id'] = df.apply(series_to_str_id, axis="columns").astype("string")
-
-    In practice it is more efficient to apply the function only to unique rows, and then merge the results.
-    """
-    # Notes:
-    #  A cache is intentionally not used because the function is expected to be called exactly once for each key.
-    #  A 50% probability of a collision is at 2**64 inputs.
-    #  A digest of length 32 must not be used because it will produce 44 base64 characters which could subsequently undesirably get mutated by Datavant Link.
-
-    # Verbose version:
-    # seed = str(tuple(pd_series)).encode()  # str(tuple(pd_series)) (without any index) is required for reproducibility.
-    # hasher = shake_128(seed)
-    # digest = hasher.digest(16)  # pylint: disable=too-many-function-args
-    # id_ = urlsafe_b64encode(digest).decode()
-    # return id_
-
-    return urlsafe_b64encode(shake_128(str(tuple(pd_series)).encode()).digest(16)).decode()  # pylint: disable=too-many-function-args
-
-
 def set_pandas_display_options() -> None:
     """Set pandas display options."""
     # Ref: https://stackoverflow.com/a/52432757/
